@@ -73,10 +73,14 @@ def get_directories(directory=None):
   if not os.path.isdir(directory):
     message.die("Directory %s does not exists" % directory)
   
-  for entry in os.scandir(directory):
-    full_name = directory + '/' + entry.name
+  subdirectories = [entry.name for entry in os.scandir(directory)]
+  subdirectories.sort()
+  
+  for entry in subdirectories:
+    full_name = directory + '/' + entry
+
     if os.path.isdir(full_name):
-      if os.path.isdir(full_name+'/.git'):
+      if os.path.isdir(full_name +'/.git'):
         directories.append(full_name)
       else:
         directories += get_directories(full_name)
@@ -128,4 +132,4 @@ def tag(directory):
 
 def is_ahead(directory):
   ret, output = subprocess.getstatusoutput("cd %s; git rev-list @{u}.." % directory)
-  return ret == 0 and output.strip() != ''
\ No newline at end of file
+  return ret == 0 and output.strip() != ''
